package com.example.mdd.service;

import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;

@Service
@Slf4j
public class HeFengDownload {
    public void download(Connection conn, String stationCode, String longitude, String latitude) {
        //和风天气api接口
        String url = "https://devapi.qweather.com/v7/grid-weather/24h?location=" + longitude + "," + latitude + "&key=54d9633382814e148836ce6be2d003fb";
        String body = HttpUtil.createGet(url).execute().charset("utf-8").body();
        JSONObject jsonObject = JSONUtil.parseObj(body);
        JSONArray list = JSONUtil.parseArray(jsonObject.get("hourly"));
        if (!list.isEmpty()) {
            String tableSql = "INSERT ignore INTO `hefeng` ( `stationCode`,`longitude`,`latitude`,`fxTime`, `temp`, `text`, `windDir`, `wind360`, `windSpeed`, `windScale`, `humidity`, `cloud`, `precip`, `dew`)" +
                    " VALUES ( ?,?,?,?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?);";
            try {
                PreparedStatement pstmt = conn.prepareStatement(tableSql);
                conn.setAutoCommit(false);
                log.info("和风天气：共{}条记录", list.size());
                list.forEach(item -> {
                    JSONObject jsonObject1 = JSONUtil.parseObj(item);
                    try {
                        pstmt.setString(1, stationCode);
                        pstmt.setString(2, longitude);
                        pstmt.setString(3, latitude);
                        pstmt.setString(4, jsonObject1.getStr("fxTime"));
                        pstmt.setString(5, jsonObject1.getStr("temp"));
                        pstmt.setString(6, jsonObject1.getStr("text"));
                        pstmt.setString(7, jsonObject1.getStr("windDir"));
                        pstmt.setString(8, jsonObject1.getStr("wind360"));
                        //公里/小时换算成m/s需要除3.6
                        pstmt.setString(9, new BigDecimal(jsonObject1.getStr("windSpeed")).divide(new BigDecimal("3.6"), 2, RoundingMode.HALF_UP).toString());
                        pstmt.setString(10, jsonObject1.getStr("windScale"));
                        pstmt.setString(11, jsonObject1.getStr("humidity"));
                        pstmt.setString(12, jsonObject1.getStr("cloud"));
                        pstmt.setString(13, jsonObject1.getStr("precip"));
                        pstmt.setString(14, jsonObject1.getStr("dew"));
                        pstmt.addBatch();
                    } catch (SQLException e) {
                        throw new RuntimeException(e);
                    }
                });
                pstmt.executeBatch();
                conn.commit();
            } catch (Exception e) {
                throw new RuntimeException(e);
            }
        }
        log.info("场站编号:{} 和风天气数据下载完成", stationCode);
    }
}
